@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dancer2::Plugin::JWT;
 # ABSTRACT: JSON Web Token made simple for Dancer2
-$Dancer2::Plugin::JWT::VERSION = '0.004';
+$Dancer2::Plugin::JWT::VERSION = '0.005';
 use Dancer2::Plugin;
 use JSON::WebToken;
 use URI;
@@ -14,7 +14,7 @@ my $config;
 
 sub _get_secret {
 	my $dsl = shift;
-	$config = $dsl->config->{plugins}{JWT};
+	$config = plugin_setting;
 	die "JWT cannot be used without a secret!" unless exists $config->{secret};
 	return $config->{secret};
 }
